svn commit: r321605 - head/contrib/ipfilter

Cy Schubert cy at FreeBSD.org
Thu Jul 27 06:26:17 UTC 2017


Author: cy
Date: Thu Jul 27 06:26:15 2017
New Revision: 321605
URL: https://svnweb.freebsd.org/changeset/base/321605

Log:
  As in r315225, discard 3072 bytes of RC4 bytestream instead of 1024.
  
  PR:		217920
  Submitted by:	codarren at hackers.mu
  Reviewed by:	emaste, cem
  Approved by:	so (implicit, in r315225)
  MFC after:	1 week
  Differential Revision:	D11747
  Patterned after:	r315225

Modified:
  head/contrib/ipfilter/arc4random.c

Modified: head/contrib/ipfilter/arc4random.c
==============================================================================
--- head/contrib/ipfilter/arc4random.c	Thu Jul 27 05:31:48 2017	(r321604)
+++ head/contrib/ipfilter/arc4random.c	Thu Jul 27 06:26:15 2017	(r321605)
@@ -109,9 +109,9 @@ arc4_randomstir (void)
 	/*
 	 * Throw away the first N words of output, as suggested in the
 	 * paper "Weaknesses in the Key Scheduling Algorithm of RC4"
 	 * by Fluher, Mantin, and Shamir.  (N = 256 in our case.)
 	 */
-	for (n = 0; n < 256*4; n++)
+	for (n = 0; n < 768*4; n++)
 		arc4_randbyte();
 	MUTEX_EXIT(&arc4_mtx);
 }
@@ -109,9 +109,9 @@ arc4_randomstir (void)
 	 * Throw away the first N words of output, as suggested in the
 	 * paper "Weaknesses in the Key Scheduling Algorithm of RC4"
-	 * by Fluher, Mantin, and Shamir.  (N = 256 in our case.)
+	 * by Fluher, Mantin, and Shamir.  (N = 768 in our case.)
 	 */


More information about the svn-src-all mailing list